# Welcome to typeshed-stats

This website provides statistics on typeshed's stubs packages.

This project was created by Alex Waygood.
It is not necessarily endorsed by any of the other typeshed maintainers.
